//Расчет результатов
function [Properties,..//Свойства
          PropertiesNames..//Имена свойств
          ]=CountCharacteristicsDynamicCurves(DynamicCurvesDatasFileName,..//Имя файла данных характеристик системы
                                              CountFunctionsFilesNames,..//Имя файла аттрибутов равномерно распределенных случайных величин
                                              PropertiesDatasFileName,..//Имя файла свойств
                                              csvSeparator,..//Разделитель .csv
                                              csvDec..//Десятичный разделитель
                                              )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Function CountCharacteristicsDynamicCurves takes 2, 3, 4 or 5 arguments');
    end
    switch nArg
    case 2 then
        PropertiesDatasFileName = [];//Имя файла результатов по умолчанию пустое
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 3 then
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 4 then
        csvDec = '.';//Десятичный разделитель
    end
    
    //Проверяем корректность аргументов
    if (type(DynamicCurvesDatasFileName) ~= 10) ||..
       (size(DynamicCurvesDatasFileName,'*') ~= 1) then
        error('The argument DynamicCurvesDatasFileName of function CountCharacteristicsDynamicCurves must be scalar string');
    end
    if (type(CountFunctionsFilesNames) ~= 10) ||..
       (size(CountFunctionsFilesNames,'*') ~= 1) then
        error('The argument CountFunctionsFilesNames of function CountCharacteristicsDynamicCurves must be scalar string');
    end
    if (~isempty(PropertiesDatasFileName)) &&.. 
       ((type(PropertiesDatasFileName) ~= 10) ||..
        (size(PropertiesDatasFileName,'*') > 1)) then
        error('The argument PropertiesDatasFileName of function CountCharacteristicsDynamicCurves must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') ~= 1) then
        error('The argument csvSeparator of function CountCharacteristicsDynamicCurves must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') ~= 1) then
        error('The argument csvDec of function CountCharacteristicsDynamicCurves must be scalar string');
    end
    
    //Считываем данные кривых из файла
    [DynamicCurvesDatas,..//Входные данные
     DynamicCurvesDatasHeaders..//Заголовки входных данных
     ]=CSVFromFileToDatas(%t,DynamicCurvesDatasFileName,..
                          csvSeparator,csvDec,%t);
    
    //Считываем функции обработки данных
    [Functions,..//Функции
     argumentsNames,..//Имена (индексы) аргументов
     rezultsNames,..//Имена результатов
     isVectorized..//Функция векторизована или нет
     ]=CountFunctionsParse(CountFunctionsFilesNames,..
                           csvSeparator,%t);
                    
    //Получаем индексы параметров системы
    Indexes = SelectionDatas(DynamicCurvesDatasHeaders,..
                             "Index",..
                             DynamicCurvesDatas);
    UnIndexes = matrix(unique(Indexes),1,-1);
    
    //Формируем заголовки свойств
    PropertiesNames = [];
    for ind=1:size(rezultsNames,'*')
        PropertiesNames = [PropertiesNames,rezultsNames{ind}];
    end
    PropertiesNames = ["Index",PropertiesNames];
    
    //Применяем функцию обработки данных к каждому индексу
    Properties = [];
    for UnIndex=UnIndexes
        //Выделяем подмножество, соответствующее индексу
        dynamicCurvesDatas = SelectionDatasSubset(DynamicCurvesDatas,Indexes == UnIndex);
        
        //Вызываем для этого подмножества функции
        properties = CountRezults(dynamicCurvesDatas,..
                                  DynamicCurvesDatasHeaders,..
                                  Functions,argumentsNames,..
                                  rezultsNames,isVectorized);
        
        //Конкатенуем с индексом
        properties = AddDatas(UnIndex,properties,[],[],'c');
        
        //Добавляем в свойства
        Properties = AddDatas(Properties,properties,[],[],'r');
    end
    
    //Анализируем необходимость индекса
    Indexes = SelectionDatas(PropertiesNames,..
                             "Index",..
                             Properties);
    if size(Indexes,'*') == size(UnIndexes,'*') then//Удаляем индекс
        [Properties,..
         PropertiesNames..
         ]=SelectionAllDatasExcept(PropertiesNames,..
                                   "Index",..
                                   Properties);
    end
    
    //Сохраняем в файл
    if ~isempty(PropertiesDatasFileName) then
        DatasToCSVFile(Properties,PropertiesNames,..
                       %t,PropertiesDatasFileName,..
                       csvSeparator,csvDec);
    end
endfunction
