//Парсим файлы данных параметров системы
function [absolutTolErr,..//Допустимая абсолютная погрешность ошибки
          relativeTolErr,..//Допустимая относительная погрешность ошибки
          simulationTime,..//Время интегрирования системы
          timeStepMax,..//Максимальный шаг интегрирования по времени
          toleranceTime,..//Время работы системы
          Solver..//Решатель
          ]=ModelingParametrsDynamicParsing(ModelingParametrsDynamicFileName,..//Имена файла параметров моделирования динамики системы
                                            SystemModelingParametrsSemanticsFileName,..//Имя файла семантики параметров моделирования динамики системы
                                            csvSeparator,..//Сепаратор данных .csv
                                            csvDec..//Десятичный разделитель в .csv файлах
                                            )
    //Обрабатываем входной аргумент
    select argn(2)
    case 0 then
        error('Functions ModelingParametrsDynamicParsing takes 1, 2, 3 or 4 arguments');
    case 1 then
        SystemModelingParametrsSemanticsFileName = [];//По умолчанию файл семантики параметров моделирования динамики системы не задан
        csvSeparator = ',';//По умолчанию разделяем запятой
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 2 then
        csvSeparator = ',';//По умолчанию разделяем запятой
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 3 then
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    end
    
    //Проверяем пустоту имени файла параметров моделирования динамики системы
    if isempty(ModelingParametrsDynamicFileName) then
        absolutTolErr = [];//Допустимая абсолютная погрешность ошибки
        relativeTolErr = [];//Допустимая относительная погрешность ошибки
        simulationTime = [];//Время интегрирования системы
        timeStepMax = [];//Максимальный шаг интегрирования по времени
        Solver = [];//Решатель
        toleranceTime = [];//Время работы системы
        
        return;
    end
    
    //Проверяем типы данных аргументов
    if (type(ModelingParametrsDynamicFileName) ~= 10) ||..
       (size(ModelingParametrsDynamicFileName,'*') > 1) then
       error('The ModelingParametrsDynamicFileName argument of function ModelingParametrsDynamicParsing must be scalar string');
    end
    if (~isempty(SystemModelingParametrsSemanticsFileName)) &&..
       ((type(SystemModelingParametrsSemanticsFileName) ~= 10) ||..
        (size(SystemModelingParametrsSemanticsFileName,'*') > 1)) then
       error('The SystemModelingParametrsSemanticsFileName argument of function ModelingParametrsDynamicParsing must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
       error('The csvSeparator argument of function ModelingParametrsDynamicParsing must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') > 1) then
       error('The csvDec argument of function ModelingParametrsDynamicParsing must be scalar string');
    end
    
    //Считываем файл параметров моделирования динамики системы
    [systemModelingParametrsValues,..//Значения параметров моделирования системы
     systemModelingParametrsNames..//Имена параметров моделирования системы
     ] = CSVFromFileToDatas(%t,ModelingParametrsDynamicFileName,..
                            csvSeparator,csvDec,%t);//Считываем параметры моделирования динамики системы 
    
    //Считываем при необходимости семантику параметров моделирования динамики системы
    if isempty(SystemModelingParametrsSemanticsFileName) then
        SystemDiagramModelingParametrsNames = systemModelingParametrsNames;//Имена параметров моделирования диаграммы системы
    else
        //Считываем семантику параметров моделирования динамики системы
        [SystemModelingParametrsNames,..//Имена параметров моделирования системы
         SystemDiagramModelingParametrsNames..//Имена параметров моделирования диаграммы системы
         ] = CSVFromFileToDatas(%t,SystemModelingParametrsSemanticsFileName,..
                                csvSeparator,csvDec,%f);
        
        //Приводим считанные параметры моделирования динамики системы в соответствие с заголовком
        [systemModelingParametrsValues,..//Выделенные данные
         SystemDiagramModelingParametrsNames..//Интерпретированный заголовок выделенных данных
         ]=SelectionDatasInterpretation(systemModelingParametrsNames,..
                                        SystemDiagramModelingParametrsNames,..
                                        SystemModelingParametrsNames,..
                                        systemModelingParametrsValues);
    end
    
    //Выделяем параметры моделирования динамики системы
    absolutTolErr = SelectionDatas(SystemDiagramModelingParametrsNames,..
                                   "absolutTolErr",..
                                   systemModelingParametrsValues);//Допустимая абсолютная погрешность ошибки
    relativeTolErr = SelectionDatas(SystemDiagramModelingParametrsNames,..
                                    "relativeTolErr",..
                                    systemModelingParametrsValues);//Допустимая относительная погрешность ошибки
    simulationTime = SelectionDatas(SystemDiagramModelingParametrsNames,..
                                    "simulationTime",..
                                    systemModelingParametrsValues);//Время интегрирования системы
    timeStepMax = SelectionDatas(SystemDiagramModelingParametrsNames,..
                                 "timeStepMax",..
                                 systemModelingParametrsValues);//Максимальный шаг интегрирования по времени
    toleranceTime = SelectionDatas(SystemDiagramModelingParametrsNames,..
                                   "toleranceTime",..
                                   systemModelingParametrsValues);//Время работы системы
    Solver = SelectionDatas(SystemDiagramModelingParametrsNames,..
                            "Solver",..
                            systemModelingParametrsValues);//Решатель
endfunction
