//Парсим файл параметров обработки выходных характеристик системы
function [typeProcessing,..//Тип процесса обработки данных
          OutputDynamicsParametrsNames,..//Выходные имена параметров динамики системы
          ProcessingSystemOutputCharacteristics..//Характеристики обработки выходных динамик системы
          ]=ProcessingSystemOutputCharacteristicsParsing(ProcessingSystemOutputCharacteristicsFileName,..//имя файла параметров обработки выходных динамик системы
                                                         sepNames..//Сепаратор имен
                                                         )
    //Обрабатываем входные аргументы
    select argn(2)
    case 0 then
        error('Functions ProcessingSystemOutputCharacteristicsParsing takes 1 or 2 arguments');
    case 1 then
        SystemOutputCharacteristicsNames = [];//Имена выходных характеристик системы неизвестны
        sepNames = ',';//По умолчанию разделяем запятой
    case 2 then
        sepNames = ',';//По умолчанию разделяем запятой
    end
    
    //Проверяем типы данных аргументов
    if (type(ProcessingSystemOutputCharacteristicsFileName) ~= 10) ||..
       (size(ProcessingSystemOutputCharacteristicsFileName,'*') > 1) then
       error('The ProcessingSystemOutputCharacteristicsFileName argument of function ProcessingSystemOutputCharacteristicsParsing must be scalar string');
    end
    if (type(SystemOutputCharacteristicsNames) ~= 10) &&..
       (size(SystemOutputCharacteristicsNames)(1) > 1) then
        error('The SystemOutputCharacteristicsNames argument of function ProcessingSystemOutputCharacteristicsParsing must be matrix 1xM of string');
    end
    if (type(sepNames) ~= 10) ||..
       (size(sepNames,'*') > 1) then
        error('The sepNames argument of function ProcessingSystemOutputCharacteristicsParsing must be scalar string');
    end
    
    /*Парсим файл инструкций обработки выходных динамик*/
    
    //Считываем инструкции из файла
    Instructions = mgetl(ProcessingSystemOutputCharacteristicsFileName);//Считываем инструкции
    
    //Предобрабатываем инструкции
    Instructions = stripblanks(Instructions);//Удаляем обрамление пробелами
    Instructions = Instructions(length(Instructions) > 0);//Удаляем пустые инструкции
    
    //Получаем тип обработки выходных данных
    typeProcessing = Instructions(1);//Тип обработки
    OutputDynamicsParametrsNames = ReadNamesFromCSV(Instructions(2),sepNames);//Получаем имена параметров динамики выходных характеристик системы
    Instructions = Instructions(3:$);//Остальные инструкции для дальнейшего парсинга
    
    //Формируем величины условий обработки выходных данных
    select typeProcessing
    case 'TimeMoments' then
        Instructions = '[' + Instructions + ']';//Добавляем скобки
        
        //Формируем cell-массив совокупностей моментов времени
        nTimesMoments = size(Instructions,'*');//Число совокупностей моментов времени
        ProcessingSystemOutputCharacteristics = cell(1, nTimesMoments);//сell-массив совокупностей моментов времени
        for ind=1:nTimesMoments
            ProcessingSystemOutputCharacteristics{ind} = evstr(Instructions(ind));//Добавляем совокупности моментов времени в массив
        end
    case 'CompressionFunctions' then
        //Получаем имена аттрибутов выходных характеристик
        ProcessingSystemOutputCharacteristics = ReadNamesFromCSV(Instructions,sepNames);
    end
endfunction
