//Парсим файлы данных параметров системы
function [SystemCharacteristicsNames,..//Имена параметров системы
          SystemCharacteristicsValues..//Значения параметров системы
          ]=SystemCharacteristicsConcatenate(SystemCharacteristicsFilesNames,..//Имена файлов данных параметров системы
                                             SystemConcatCharacteristicsFileName,..//Имя файла конкатенованных характеристик
                                             csvSeparator,..//Сепаратор данных .csv
                                             csvDec,..//Десятичный разделитель в .csv файлах
                                             csvParsing..//Необходимость парсинга .csv файла
                                             )
    //Обрабатываем входной аргумент
    select argn(2)
    case 0 then
        error('Functions SystemCharacteristicsConcatenate takes 1, 2, 3, 4 or 5 arguments');
    case 1 then
        SystemConcatCharacteristicsFileName = [];//Имя файла конкатенованных характеристик по умолчанию пустое
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
        csvParsing = %t;//По умолчанию парсим .csv файл
    case 2 then
        if type(SystemConcatCharacteristicsFileName) == 4 then
            csvParsing = SystemConcatCharacteristicsFileName;
            SystemConcatCharacteristicsFileName = [];//Имя файла конкатенованных характеристик по умолчанию пустое
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 3 then
        if type(csvSeparator) == 4 then
            csvParsing = csvSeparator;
            csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 4 then
        if type(csvDec) == 4 then
            csvParsing = csvDec;
            csvDec = '.';//По умолчанию десятичный разделитель - точка
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
    end
    
    //Проверяем типы данных аргументов
    if (~isempty(SystemCharacteristicsFilesNames)) &&..
       (type(SystemCharacteristicsFilesNames) ~= 10) then
       error('The SystemCharacteristicsFilesNames argument of function SystemCharacteristicsConcatenate must be matrix of string');
    end
    if (~isempty(SystemConcatCharacteristicsFileName)) &&..
       ((type(SystemConcatCharacteristicsFileName) ~= 10) ||..
        (size(SystemConcatCharacteristicsFileName,'*') > 1)) then
       error('The SystemConcatCharacteristicsFileName argument of function SystemCharacteristicsConcatenate must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
       error('The csvSeparator argument of function SystemCharacteristicsConcatenate must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') > 1) then
       error('The csvDec argument of function SystemCharacteristicsConcatenate must be scalar string');
    end
    if (type(csvParsing) ~= 4) ||..
       (size(csvParsing,'*') > 1) then
       error('The csvParsing argument of function SystemCharacteristicsConcatenate must be scalar boolean');
    end
    
    //Парсим файлы параметров системы   
    SystemCharacteristicsNames = [];//Имена параметров диаграммы системы
    SystemCharacteristicsValues = [];//Значения параметров диаграммы системы
    for systemCharacteristicsFilesNames=SystemCharacteristicsFilesNames//Читаем каждый файл параметров системы и условий протекания процессов в системе  
        systemCharacteristicsNames = [];//Имена параметров
        systemCharacteristicsValues = [];//Значения параметров
        for systemCharacteristicsFileName=systemCharacteristicsFilesNames'
            //Считываем имена и значения параметров из файла параметров
            [_systemCharacteristicsValues,..//Значения параметров
             _systemCharacteristicsNames..//Имена параметров
             ] = CSVFromFileToDatas(%t,systemCharacteristicsFileName,..
                                    csvSeparator,csvDec,csvParsing);
        
            //Добавляем считанные параметры в массив
            [systemCharacteristicsValues,..
             systemCharacteristicsNames]=AddDatas(systemCharacteristicsValues,_systemCharacteristicsValues,..
                                                  systemCharacteristicsNames,_systemCharacteristicsNames,'r');
        end
        
        //Добавляем считанные параметры в массив
        [SystemCharacteristicsValues,..
         SystemCharacteristicsNames]=AddDatas(SystemCharacteristicsValues,systemCharacteristicsValues,..
                                              SystemCharacteristicsNames,systemCharacteristicsNames,'c');
    end
    
    //Сохраняем характеристики системы в файл
    if ~isempty(SystemConcatCharacteristicsFileName) then
        DatasToCSVFile(SystemCharacteristicsValues,..
                       SystemCharacteristicsNames,..
                       %t,SystemConcatCharacteristicsFileName,..
                       csvSeparator,csvDec);
    end
endfunction
