//Парсим файлы данных параметров системы
function [SystemCharacteristicsNames,..//Имена параметров системы
          SystemCharacteristicsValues..//Значения параметров системы
          ]=SystemDynamicsCurveAndCharacteristicsConcatenate(DynamicsCurveFilesNames,..//Имена файлов данных параметров системы
                                                             SystemCharacteristicsFilesNames,..//Имена файлов данных параметров системы
                                                             SystemConcatCharacteristicsFileName,..//Имя файла конкатенованных характеристик
                                                             csvSeparator,..//Сепаратор данных .csv
                                                             csvDec..//Десятичный разделитель в .csv файлах
                                                             )
    //Обрабатываем входной аргумент
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Functions SystemDynamicsCurveAndCharacteristicsConcatenate takes 2, 3, 4 or 5 arguments');
    end
    select nArg
    case 2 then
        SystemConcatCharacteristicsFileName = [];//Имя файла конкатенованных характеристик по умолчанию пустое
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 3 then
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 4 then
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    end
    
    //Проверяем типы данных аргументов
    if (~isempty(DynamicsCurveFilesNames)) &&..
       (type(DynamicsCurveFilesNames) ~= 10) then
       error('The PartsDatasFilesNames argument of function SystemDynamicsCurveAndCharacteristicsConcatenate must be matrix of string');
    end
    if (~isempty(SystemCharacteristicsFilesNames)) &&..
       (type(SystemCharacteristicsFilesNames) ~= 10) then
       error('The SystemCharacteristicsFilesNames argument of function SystemDynamicsCurveAndCharacteristicsConcatenate must be matrix of string');
    end
    if (~isempty(SystemConcatCharacteristicsFileName)) &&..
       ((type(SystemConcatCharacteristicsFileName) ~= 10) ||..
        (size(SystemConcatCharacteristicsFileName,'*') > 1)) then
       error('The SystemConcatCharacteristicsFileName argument of function SystemDynamicsCurveAndCharacteristicsConcatenate must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
       error('The csvSeparator argument of function SystemDynamicsCurveAndCharacteristicsConcatenate must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') > 1) then
       error('The csvDec argument of function SystemDynamicsCurveAndCharacteristicsConcatenate must be scalar string');
    end
    
    //Парсим файлы характеристик системы
    [SystemCharacteristicsNames,..//Имена параметров системы
     SystemCharacteristicsValues..//Значения параметров системы
     ]=SystemCharacteristicsConcatenate(SystemCharacteristicsFilesNames,..
                                        [],csvSeparator,csvDec,%t);
    
    //Парсим файлы динамических кривых системы
    [DynamicsNames,..//Имена параметров системы
     DynamicsValues..//Значения параметров системы
     ]=SystemDynamicsCurveConcatenate(DynamicsCurveFilesNames,..
                                      [],csvSeparator,csvDec);
                                      
    //Конкатенуем считанные данные
    if ~isempty(DynamicsValues) then
        //Получаем индексы динамических кривых
        [Index,DynamicsValues,..
         _Index,DynamicsNames]=InputOutputDataSplit(DynamicsNames,..
                                                    DynamicsValues,..
                                                    "Index");
                               
        //Выбираем параметры в соответствие с индексами
        SystemCharacteristicsValues = SelectionDatasSubset(SystemCharacteristicsValues,Index);
        
        //Конкатенуем динамики с характеристиками системы
        [SystemCharacteristicsValues,..
         SystemCharacteristicsNames]=AddDatas(SystemCharacteristicsValues,DynamicsValues,..
                                              SystemCharacteristicsNames,DynamicsNames,'c');
    end
    
    //Сохраняем характеристики системы в файл
    if ~isempty(SystemConcatCharacteristicsFileName) then
        DatasToCSVFile(SystemCharacteristicsValues,..
                       SystemCharacteristicsNames,..
                       %t,SystemConcatCharacteristicsFileName,..
                       csvSeparator,csvDec);
    end
endfunction
