//Парсим файлы данных параметров системы
function [DynamicsNames,..//Имена параметров системы
          DynamicsValues..//Значения параметров системы
          ]=SystemDynamicsCurveConcatenate(DynamicsCurveFilesNames,..//Имена файлов данных параметров системы
                                           SystemConcatDynamicsCurvesFileName,..//Имя файла конкатенованных кривых динамик
                                           csvSeparator,..//Сепаратор данных .csv
                                           csvDec..//Десятичный разделитель в .csv файлах
                                           )
    //Обрабатываем входной аргумент
    select argn(2)
    case 0 then
        error('Functions SystemDynamicsCurveConcatenate takes 1, 2, 3 or 4 arguments');
    case 1 then
        SystemConcatDynamicsCurvesFileName = [];//Имя файла конкатенованных кривых динамик по умолчанию берем пустым
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 2 then
        csvSeparator = ',';//По умолчанию разделитель .csv - запятая
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 3 then
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    end
    
    //Проверяем типы данных аргументов
    if (~isempty(DynamicsCurveFilesNames)) &&..
       (type(DynamicsCurveFilesNames) ~= 10) then
       error('The PartsDatasFilesNames argument of function SystemDynamicsCurveConcatenate must be matrix of string');
    end
    if (~isempty(SystemConcatDynamicsCurvesFileName)) &&..
       ((type(SystemConcatDynamicsCurvesFileName) ~= 10) ||..
        (size(SystemConcatDynamicsCurvesFileName,'*') > 1)) then
       error('The SystemConcatDynamicsCurvesFileName argument of function SystemDynamicsCurveConcatenate must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
       error('The csvSeparator argument of function SystemDynamicsCurveConcatenate must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') > 1) then
       error('The csvDec argument of function SystemDynamicsCurveConcatenate must be scalar string');
    end
    
    //Парсим файлы параметров системы   
    DynamicsNames = [];//Имена кривых динамик системы
    DynamicsValues = [];//Значения кривых динамик системы
    moveIndex = 0;//Смещение индекса
    for DynamicsCurveFileName=matrix(DynamicsCurveFilesNames,1,-1)//Читаем каждый файл параметров системы и условий протекания процессов в системе  
        //Считываем кривые динамики из файла
        [dynamicsValues,..//Значения параметров
         dynamicsNames..//Имена параметров
         ] = CSVFromFileToDatas(%t,DynamicsCurveFileName,..
                                csvSeparator,csvDec,%t);
        
        //Корректируем индекс
        Index = SelectionDatas(dynamicsNames,..
                               "Index",..
                               dynamicsValues);
        Index = Index + moveIndex;//Корректируем  индекс
        moveIndex = Index($);//Обновляем смещение индекса
        [dynamicsValues,..
         dynamicsNames] = AddDatas(Index,dynamicsValues,..
                                   "Index",dynamicsNames,'c',%f);
        
        //Добавляем считанные параметры в массив
        [DynamicsValues,..
         DynamicsNames]=AddDatas(DynamicsValues,dynamicsValues,..
                                 DynamicsNames,dynamicsNames,'r');
    end
    
    //Сохраняем характеристики системы в файл
    if ~isempty(SystemConcatDynamicsCurvesFileName) then
        DatasToCSVFile(DynamicsValues,DynamicsNames,%t,..
                       SystemConcatDynamicsCurvesFileName,..
                       csvSeparator,csvDec);
    end
endfunction
