//Парсим функции сжатия выходных динамик системы
function [SystemOutputCharacteristicsCompressionFunctions,..//Имена функций сжатия выходных динамик системы
          OutputDynamicsParametrsNames,..//Выходные имена параметров динамики системы
          SystemOutputCharacteristicsNames..//Имена выходных характеристик системы
          ]=SystemOutputCharCompresFunctionsParsing(strSystemOutputCharCompresFunctions,..//Характеристики обработки выходных динамик системы
                                                    SystemOutputCharacteristicsNames,..//Имена выходных характеристик системы (в порядке их следования на диаграмме системы)
                                                    sepNames..//Сепаратор имен
                                                    )
    //Обрабатываем входные аргументы
    select argn(2)
    case 0 then
        error('Functions SystemOutputCharCompresFunctionsParsing takes 1, 2 or 3 arguments');
    case 1 then
        SystemOutputCharacteristicsNames = [];//Имена выходных характеристик системы неизвестны
        sepNames = ',';//По умолчанию разделяем запятой
    case 2 then
        sepNames = ',';//По умолчанию разделяем запятой
    end
    
    //Проверяем корректность входных аргументов
    if (isempty(strSystemOutputCharCompresFunctions)) ||..
       (type(strSystemOutputCharCompresFunctions) ~= 10) ||..
       (size(strSystemOutputCharCompresFunctions)(1) ~= 3) then
        error('The argument strSystemOutputCharCompresFunctions of function SystemOutputCharCompresFunctionsParsing must be matrix of strings 3xM');
    end
    if (~isempty(SystemOutputCharacteristicsNames)) &&..
       ((type(SystemOutputCharacteristicsNames) ~= 10) ||..
        (size(SystemOutputCharacteristicsNames)(1) ~= 1)) then
        error('The argument SystemOutputCharacteristicsNames of function SystemOutputCharCompresFunctionsParsing must be matrix of strings 1xM');
    end
    if isempty(sepNames) || (type(sepNames) ~= 10) ||..
       (size(sepNames,'*') > 1) then
        error('The argument sepNames of function SystemOutputCharCompresFunctionsParsing must be string scalar');
    end
    
    //Приводим функции сжатия в соответсвие с именами выходных характеристик
    systemOutputCharacteristicsNames = SelectionDatasSubset(strSystemOutputCharCompresFunctions,2);//Получаем заголовки выходных характеристик системы
    strSystemOutputCharCompresFunctions = EraseDatasSubset(strSystemOutputCharCompresFunctions,2);//Удаляем из инструкций обработки выходных характеристик системы заголовок
    if isempty(SystemOutputCharacteristicsNames) then
        SystemOutputCharacteristicsNames = systemOutputCharacteristicsNames;
    else
        [strSystemOutputCharCompresFunctions,..
         SystemOutputCharacteristicsNames] = SelectionDatas(systemOutputCharacteristicsNames,..
                                                            SystemOutputCharacteristicsNames,..
                                                            strSystemOutputCharCompresFunctions);//Приводим имена и характеристики в соответствие
    end

    //Получаем имена параметров динамик выходных характеристик системы
    csvOutputDynamicsParametrsNames = SelectionDatasSubset(strSystemOutputCharCompresFunctions,2);//Получаем параметры динамик выходных характеристик системы в формате .csv
    OutputDynamicsParametrsNames = [];
    for csvOutputDynamicParametrsNames=csvOutputDynamicsParametrsNames
        cOutputDynamicsParametrsNames = ReadNamesFromCSV(csvOutputDynamicParametrsNames,sepNames);//Парсим строку
        OutputDynamicsParametrsNames = [OutputDynamicsParametrsNames,..
                                        cOutputDynamicsParametrsNames];//Добавляем в имена динамик выходных параметров системы
    end
    
    //Получаем имена функций сжатия выходных динамик системы
    SystemOutputCharacteristicsCompressionFunctions = SelectionDatasSubset(strSystemOutputCharCompresFunctions,1);
endfunction
