//Парсим файлы данных параметров системы
function [SystemDiagramParametrsValues,..//Значения параметров диаграммы системы
          SystemDiagramParametrsNames,..//Имена параметров диаграммы системы
          SystemParametrsNames..//Имена параметров системы
          ]=SystemParametrsParsing(SystemParametrsDatasFilesNames,..//Имена файлов данных параметров системы
                                   ConditionDatasFileName,..//Имя файла данных условий функционирования системы
                                   SystemParametrsSemanticsFileName,..//Имя файла семандики параметров системы
                                   csvSeparator,..//Сепаратор данных .csv
                                   csvDec,..//Десятичный разделитель в .csv файлах
                                   csvParsing..//Необходимость парсинга .csv файла
                                   )
    //Обрабатываем входной аргумент
    select argn(2)
    case 0 then
        error('Functions SystemParametrsParsing takes 1, 2, 3, 4, 5 or 6 arguments');
    case 1 then
        ConditionDatasFileName = [];//По умолчанию имя файла условий протекания процессов в системе пустое
        SystemParametrsSemanticsFileName = [];//По умолчанию файл семантики параметров системы не задан
        csvSeparator = ',';//По умолчанию разделяем запятой
        csvDec = '.';//По умолчанию десятичный разделитель - точка
        csvParsing = %t;//По умолчанию парсим .csv файл
    case 2 then
        if type(ConditionDatasFileName) == 4 then
            csvParsing = ConditionDatasFileName;
            ConditionDatasFileName = [];//По умолчанию имя файла условий протекания процессов в системе пустое
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
        SystemParametrsSemanticsFileName = [];//По умолчанию файл семантики параметров системы не задан
        csvSeparator = ',';//По умолчанию разделяем запятой
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 3 then
        if type(SystemParametrsSemanticsFileName) == 4 then
            csvParsing = SystemParametrsSemanticsFileName;
            SystemParametrsSemanticsFileName = [];//По умолчанию файл семантики параметров системы не задан
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
        csvSeparator = ',';//По умолчанию разделяем запятой
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 4 then
        if type(csvSeparator) == 4 then
            csvParsing = csvSeparator;
            csvSeparator = ',';//По умолчанию разделяем запятой
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
        csvDec = '.';//По умолчанию десятичный разделитель - точка
    case 5 then
        if type(csvDec) == 4 then
            csvParsing = csvDec;
            csvDec = '.';//По умолчанию десятичный разделитель - точка
        else
            csvParsing = %t;//По умолчанию парсим .csv файл
        end
    end
    
    //Проверяем типы данных аргументов
    if (~isempty(SystemParametrsDatasFilesNames)) &&..
       (type(SystemParametrsDatasFilesNames) ~= 10) then
       error('The SystemParametrsDatasFilesNames argument of function SystemParametrsParsing must be matrix of string');
    end
    if (~isempty(ConditionDatasFileName)) &&..
       ((type(ConditionDatasFileName) ~= 10) ||..
        (size(ConditionDatasFileName,'*') > 1)) then
       error('The ConditionDatasFileName argument of function SystemParametrsParsing must be scalar string');
    end
    if (~isempty(SystemParametrsSemanticsFileName)) &&..
       ((type(SystemParametrsSemanticsFileName) ~= 10) ||..
        (size(SystemParametrsSemanticsFileName,'*') > 1)) then
       error('The SystemParametrsSemanticsFileName argument of function SystemParametrsParsing must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
       error('The csvSeparator argument of function SystemParametrsParsing must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') > 1) then
       error('The csvDec argument of function SystemParametrsParsing must be scalar string');
    end
    if (type(csvParsing) ~= 4) ||..
       (size(csvParsing,'*') > 1) then
       error('The csvParsing argument of function SystemParametrsParsing must be scalar boolean');
    end
    
    //Парсим файлы параметров системы
    [systemDiagramParametrsNames,..//Имена параметров системы
     systemDiagramParametrsValues..//Значения параметров системы
     ]=SystemParametrsDatasParsing(SystemParametrsDatasFilesNames,..//Имена файлов данных параметров системы
                                   ConditionDatasFileName,..//Имя файла данных условий функционирования системы
                                   csvSeparator,..//Сепаратор данных .csv
                                   csvDec,..//Десятичный разделитель в .csv файлах
                                   %f..//Файлы .csv не парсим
                                   );//Считываем параметры диаграммы системы
    if isempty(SystemParametrsSemanticsFileName) then
        SystemParametrsNames = systemDiagramParametrsNames;//Имена параметров системы
        SystemDiagramParametrsNames = systemDiagramParametrsNames;//Имена параметров диаграммы системы
        SystemDiagramParametrsValues = systemDiagramParametrsValues;//Значения параметров системы
    else
        [SystemParametrsNames,..//Имена параметров системы
         SystemDiagramParametrsNames..//Имена параметров диаграммы системы
         ] = CSVFromFileToDatas(%t,SystemParametrsSemanticsFileName,csvSeparator,..
                                csvDec,%f);//Считываем семантику параметров (данные не парсим)
        
        //Выделяем параметры диаграммы системы
        [SystemDiagramParametrsValues,..//Значения параметров диаграммы системы
         SystemDiagramParametrsNames,..//Имена параметров диаграммы системы
         SystemParametrsNames..//Имена параметров системы
         ]=SelectionDatasInterpretation(systemDiagramParametrsNames,..
                                        SystemDiagramParametrsNames,..
                                        SystemParametrsNames,..
                                        systemDiagramParametrsValues);
    end
endfunction
